==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-core/src/main/java/org/apache/maven/session/scope/internal/SessionScopeModule.java <==
package org.apache.maven.session.scope.internal;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import javax.inject.Inject;
import javax.inject.Named;

import org.apache.maven.SessionScoped;
import org.apache.maven.execution.MavenSession;
import org.codehaus.plexus.PlexusContainer;
import org.codehaus.plexus.component.repository.exception.ComponentLookupException;

import com.google.inject.AbstractModule;

/**
 * SessionScopeModule
 */
@Named
public class SessionScopeModule
    extends AbstractModule
{
    private final SessionScope scope;

    @Inject
    public SessionScopeModule()
    {
        this( new SessionScope() );
    }

    public SessionScopeModule( PlexusContainer container )
        throws ComponentLookupException
    {
        this( container.lookup( SessionScope.class ) );
    }

    private SessionScopeModule( SessionScope scope )
    {
        this.scope = scope;
    }

    @Override
    protected void configure()
    {
        bindScope( SessionScoped.class, scope );
        bind( SessionScope.class ).toInstance( scope );

        bind( MavenSession.class ).toProvider( SessionScope.<MavenSession>seededKeyProvider() ).in( scope );
    }
}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-core/src/main/java/org/apache/maven/session/scope/internal/SessionScopeModule.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.session.scope.internal;

import javax.inject.Inject;
import javax.inject.Named;

import com.google.inject.AbstractModule;
import org.apache.maven.SessionScoped;
import org.apache.maven.execution.MavenSession;
import org.codehaus.plexus.PlexusContainer;
import org.codehaus.plexus.component.repository.exception.ComponentLookupException;

/**
 * SessionScopeModule
 */
@Named
public class SessionScopeModule extends AbstractModule {
    private final SessionScope scope;

    @Inject
    public SessionScopeModule() {
        this(new SessionScope());
    }

    public SessionScopeModule(PlexusContainer container) throws ComponentLookupException {
        this(container.lookup(SessionScope.class));
    }

    private SessionScopeModule(SessionScope scope) {
        this.scope = scope;
    }

    @Override
    protected void configure() {
        bindScope(SessionScoped.class, scope);
        bind(SessionScope.class).toInstance(scope);

        bind(MavenSession.class)
                .toProvider(SessionScope.<MavenSession>seededKeyProvider())
                .in(scope);
    }
}
